==> aws-cdk.aws-autoscalingplans-1.149.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_autoscalingplans_CfnScalingPlanProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.applicationSource))
        _aws_cdk_aws_autoscalingplans_CfnScalingPlan_ApplicationSourceProperty(p.applicationSource);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_MetricDimensionProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_PredefinedLoadMetricSpecificationProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_PredefinedScalingMetricSpecificationProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_TagFilterProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_CustomizedScalingMetricSpecificationProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_CustomizedLoadMetricSpecificationProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_ApplicationSourceProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_TargetTrackingConfigurationProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_ScalingInstructionProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_autoscalingplans_CfnScalingPlanProps, _aws_cdk_aws_autoscalingplans_CfnScalingPlan, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_MetricDimensionProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_PredefinedLoadMetricSpecificationProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_PredefinedScalingMetricSpecificationProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_TagFilterProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_CustomizedScalingMetricSpecificationProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_CustomizedLoadMetricSpecificationProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_ApplicationSourceProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_TargetTrackingConfigurationProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_ScalingInstructionProperty };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-autoscalingplans-1.151.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_autoscalingplans_CfnScalingPlanProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.applicationSource))
        _aws_cdk_aws_autoscalingplans_CfnScalingPlan_ApplicationSourceProperty(p.applicationSource);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_MetricDimensionProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_PredefinedLoadMetricSpecificationProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_PredefinedScalingMetricSpecificationProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_TagFilterProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_CustomizedLoadMetricSpecificationProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_CustomizedScalingMetricSpecificationProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_ApplicationSourceProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_TargetTrackingConfigurationProperty(p) {
}
function _aws_cdk_aws_autoscalingplans_CfnScalingPlan_ScalingInstructionProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_autoscalingplans_CfnScalingPlanProps, _aws_cdk_aws_autoscalingplans_CfnScalingPlan, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_MetricDimensionProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_PredefinedLoadMetricSpecificationProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_PredefinedScalingMetricSpecificationProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_TagFilterProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_CustomizedLoadMetricSpecificationProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_CustomizedScalingMetricSpecificationProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_ApplicationSourceProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_TargetTrackingConfigurationProperty, _aws_cdk_aws_autoscalingplans_CfnScalingPlan_ScalingInstructionProperty };
module.exports.DeprecationError = DeprecationError;
